# rotalabs-audit

Reasoning chain capture for auditing from [Rotalabs](https://rotalabs.ai).

**This is a placeholder package. Full implementation coming soon.**

## Links

- Website: https://rotalabs.ai
- GitHub: https://github.com/rotalabs/rotalabs-audit
- Contact: research@rotalabs.ai
